@@ -39,6 +39,7 @@ pref("security.warn_entering_secure", false);
 pref("security.warn_entering_secure.show_once", true);
 pref("security.warn_leaving_secure", false);
 pref("security.warn_submit_insecure", false);
+pref("security.warn_submit_insecure.show_once", false);
 
 // fonts
 pref("font.size.unit", "pt");
@@ -88,5 +89,4 @@ pref("xpinstall.enabled", false);
 
 // enable typeahead find
 pref("accessibility.typeaheadfind", true);
-// see bug #141963
-pref("accessibility.typeaheadfind.autostart", false);
+
