@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-download.c,v 1.6.4.2 2004/09/22 12:49:41 chpe Exp $
+ *  $Id: ephy-download.c,v 1.11 2005/01/08 19:41:46 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-download.h"
 
@@ -41,7 +39,7 @@ enum
 	LAST_SIGNAL
 };
 
-struct EphyDownloadPrivate
+struct _EphyDownloadPrivate
 {
 	long remaining_time_last_update;
 	long remaining_time;
@@ -54,9 +52,9 @@ static guint ephy_download_signals[LAST_SIGNAL] = { 0 };
 GType
 ephy_download_get_type (void)
 {
-       static GType ephy_download_type = 0;
+       static GType type = 0;
 
-        if (ephy_download_type == 0)
+        if (G_UNLIKELY (type == 0))
         {
                 static const GTypeInfo our_info =
                 {
@@ -71,12 +69,12 @@ ephy_download_get_type (void)
                         (GInstanceInitFunc) ephy_download_init
                 };
 
-                ephy_download_type = g_type_register_static (G_TYPE_OBJECT,
-                                                             "EphyDownload",
-                                                             &our_info, 0);
+                type = g_type_register_static (G_TYPE_OBJECT,
+					       "EphyDownload",
+					       &our_info, 0);
         }
 
-        return ephy_download_type;
+        return type;
 }
 
 static void
