@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.36 2005/01/24 13:43:58 chpe Exp $
+ *  $Id: MozRegisterComponents.cpp,v 1.37 2005/02/07 23:04:10 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -109,7 +109,11 @@ static const nsModuleComponentInfo sAppComps[] = {
 	{
 		MOZ_DOWNLOAD_CLASSNAME,
 		MOZ_DOWNLOAD_CID,
+#ifdef NS_TRANSFER_CONTRACTID
+		NS_TRANSFER_CONTRACTID,
+#else
 		NS_DOWNLOAD_CONTRACTID,
+#endif
 		MozDownloadConstructor
 	},
 #ifdef ENABLE_FILEPICKER
