@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.106 2005/01/30 15:20:35 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.109 2005/02/26 22:48:16 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -85,7 +85,7 @@
 #include <nsIFontEnumerator.h>
 #include <nsNetCID.h>
 #include <nsIIDNService.h>
-#endif
+#endif /* ALLOW_PRIVATE_API */
 
 #include <stdlib.h>
 
@@ -245,6 +245,8 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
 	pref->SetBoolPref("network.protocol-handler.external.ftp",
 			  have_gnome_url_handler ("ftp"));
 
+	MozillaPrivate::SecureWallet (pref);
+
 	return TRUE;
 }
 
@@ -332,11 +334,13 @@ mozilla_embed_single_new_window_orphan_cb (GtkMozEmbedSingle *moz_single,
 	g_signal_emit_by_name (single, "new-window", NULL, mask,
 			       &new_embed);
 
-	g_assert (new_embed != NULL);
+	/* it's okay not to have a new embed */
+	if (new_embed != NULL)
+	{
+		gtk_moz_embed_set_chrome_mask (GTK_MOZ_EMBED (new_embed), chrome);
 
-	gtk_moz_embed_set_chrome_mask (GTK_MOZ_EMBED (new_embed), chrome);
-
-	*newEmbed = GTK_MOZ_EMBED (new_embed);
+		*newEmbed = GTK_MOZ_EMBED (new_embed);
+	}
 }
 
 static void
