@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-chooser.c,v 1.19 2005/01/08 19:41:46 chpe Exp $
+ *  $Id: ephy-file-chooser.c,v 1.20 2005/01/28 22:24:03 chpe Exp $
  */
 
 #include "config.h"
@@ -128,7 +128,7 @@ ephy_file_chooser_finalize (GObject *object)
 
 	g_free (dialog->priv->persist_key);
 
-	LOG ("EphyFileChooser finalised")
+	LOG ("EphyFileChooser finalised");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
