@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node.h,v 1.19 2005/01/08 19:41:46 chpe Exp $
+ *  $Id: ephy-node.h,v 1.21 2005/01/16 21:17:54 jframeau Exp $
  */
 
 #ifndef EPHY_NODE_H
@@ -28,8 +28,7 @@
 
 G_BEGIN_DECLS
 
-/* convenience macro to check node validity */
-
+#define EPHY_TYPE_NODE	(ephy_node_get_type ())
 #define EPHY_IS_NODE(o)	(o != NULL)
 
 typedef struct _EphyNode EphyNode;
@@ -49,6 +48,8 @@ typedef enum
 
 typedef void (*EphyNodeCallback) (EphyNode *node, ...);
 
+GType	    ephy_node_get_type		    (void) G_GNUC_CONST;
+
 EphyNode   *ephy_node_new                   (EphyNodeDb *db);
 
 EphyNode   *ephy_node_new_with_id           (EphyNodeDb *db,
@@ -99,9 +100,6 @@ float       ephy_node_get_property_float    (EphyNode *node,
 					     guint property_id);
 EphyNode   *ephy_node_get_property_node     (EphyNode *node,
 					     guint property_id);
-/* free return value */
-char       *ephy_node_get_property_time     (EphyNode *node,
-					     guint property_id);
 
 /* xml storage */
 int           ephy_node_write_to_xml	    (EphyNode *node,
