@@ -1,7 +1,7 @@
 /*
  *  Copyright (C) 2002  Ricardo Fernández Pascual
- *  Copyright (C) 2003  Marco Pesenti Gritti
- *  Copyright (C) 2003  Christian Persch
+ *  Copyright (C) 2003, 2004  Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004, 2005  Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.h,v 1.14 2005/01/08 14:02:20 chpe Exp $
+ *  $Id: ephy-location-entry.h,v 1.18 2005/02/06 14:37:12 chpe Exp $
  */
 
 #ifndef EPHY_LOCATION_ENTRY_H
@@ -48,6 +48,7 @@ struct _EphyLocationEntryClass
 
 	/* Signals */
 	void	(*user_changed)	  (EphyLocationEntry *entry);
+	void	(* lock_clicked)  (EphyLocationEntry *entry);
 	/* for getting the drag data */
 	char *	(* get_location)  (EphyLocationEntry *entry);
 	char *	(* get_title)     (EphyLocationEntry *entry);
@@ -81,7 +82,17 @@ void		ephy_location_entry_activate		(EphyLocationEntry *le);
 
 GtkWidget      *ephy_location_entry_get_entry		(EphyLocationEntry *entry);
 
-GtkWidget      *ephy_location_entry_get_image		(EphyLocationEntry *entry);
+void		ephy_location_entry_set_favicon		(EphyLocationEntry *entry,
+							 GdkPixbuf *pixbuf);
+
+void		ephy_location_entry_set_show_lock	(EphyLocationEntry *entry,
+							 gboolean show_lock);
+
+void		ephy_location_entry_set_lock_stock	(EphyLocationEntry *entry,
+							 const char *stock_id);
+
+void		ephy_location_entry_set_lock_tooltip	(EphyLocationEntry *entry,
+							 const char *tooltip);
 
 G_END_DECLS
 
