@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-dialog.c,v 1.20 2005/01/08 19:41:47 chpe Exp $
+ *  $Id: ephy-encoding-dialog.c,v 1.21 2005/01/21 19:33:02 jbaayen Exp $
  */
 
 #include "config.h"
@@ -311,7 +311,7 @@ ephy_encoding_dialog_init (EphyEncodingDialog *dialog)
 				   G_TYPE_STRING,
 				   EPHY_NODE_ENCODING_PROP_TITLE_ELIDED,
 				   EPHY_NODE_VIEW_SEARCHABLE,
-				   NULL);
+				   NULL, NULL);
 
 	ephy_node_view_set_sort (EPHY_NODE_VIEW (treeview), G_TYPE_STRING,
 				 EPHY_NODE_ENCODING_PROP_TITLE_ELIDED,
