@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-menu.c,v 1.32 2004/12/13 18:58:58 chpe Exp $
+ *  $Id: ephy-encoding-menu.c,v 1.33 2005/01/28 22:24:45 chpe Exp $
  */
 
 #include "config.h"
@@ -290,7 +290,7 @@ add_action (EphyNode *encodings, EphyNode *node, EphyEncodingMenu *menu)
 	title = ephy_node_get_property_string
 			(node, EPHY_NODE_ENCODING_PROP_TITLE);
 
-	LOG ("add_action for encoding '%s'", encoding)
+	LOG ("add_action for encoding '%s'", encoding);
 
 	g_snprintf (name, sizeof (name), "Encoding%s", encoding);
 
